@@ -1,9 +1,9 @@
 """
-Version 0.0.7
+Version 0.0.13
 Author: Deskent
 """
 
-from decimal import Decimal
+from decimal import Decimal, getcontext
 from functools import wraps
 from typing import Optional, Callable, Any
 
@@ -11,13 +11,22 @@ import bitcoinlib
 from bitcoinlib.wallets import Wallet, wallet_delete, WalletError, WalletTransaction
 from bitcoinlib.mnemonic import Mnemonic
 from bitcoinlib.keys import HDKey
-from exceptions import PassphraseError, WalletExists
 from myloguru.my_loguru import get_logger
 
-
+getcontext().prec = 5
 logger = get_logger(level=20)
 
 
+class PassphraseError(Exception):
+    def __str__(self):
+        return "Wrong passphrase"
+
+
+class WalletExists(Exception):
+    def __str__(self):
+        return "Wallet exists"
+
+
 def load_wallet_data(func: Callable) -> Callable:
     """Decorator for create wallet inside instance if wallet is not exists"""
 
